package joptsimple.examples;

import java.io.File;
import java.io.OutputStreamWriter;
import java.io.PrintStream;
import java.io.PrintWriter;
import java.io.Writer;
import java.util.ArrayList;
import java.util.List;

class Command {
    private boolean flag;
    private int count;
    private double quantity;
    private Writer output;
    private boolean operateVerbosely;
    private List<File> path = new ArrayList<File>();

    Command( PrintStream out ) {
        this.output = new OutputStreamWriter( out );
    }

    void setFlag( boolean flag ) {
        this.flag = flag;
    }

    void setCount( int count ) {
        this.count = count;
    }

    void setQuantity( double quantity ) {
        this.quantity = quantity;
    }

    void setOutput( Writer output ) {
        if ( output != null )
            this.output = output;
    }

    void setOperateVerbosely( boolean operateVerbosely ) {
        this.operateVerbosely = operateVerbosely;
    }

    void setPath( List<File> directories ) {
        this.path.addAll( directories );
    }

    boolean isReady() {
        return output != null;
    }

    void execute() {
        printSummary( buildSummary() );
    }

    private String buildSummary() {
        StringBuilder buffer = new StringBuilder();

        if ( operateVerbosely )
            buffer.append( "The following are the settings of this command: " );

        buffer.append( "flag = " ).append( flag );
        buffer.append( ", count = " ).append( count );
        buffer.append( ", quantity = " ).append( quantity );
        buffer.append( ", path = " ).append( path );

        if ( operateVerbosely )
            buffer.append( ".  Thank you for your attention." );

        return buffer.toString();
    }

    private void printSummary( String summary ) {
        PrintWriter printer = null;

        try {
            printer = new PrintWriter( output, true );
            printer.println( summary );
        }
        finally {
            if ( printer != null )
                printer.close();
        }
    }
}
