package joptsimple.examples;

import static java.io.File.*;
import static java.util.Arrays.*;

import java.io.File;
import java.io.FileWriter;

import joptsimple.OptionParser;
import joptsimple.OptionSet;
import joptsimple.OptionSpec;

public class FluentInterfaceExample {
    public static void main( String[] args ) throws Exception {
        OptionParser parser = new OptionParser();

        OptionSpec<Void> flag = parser.accepts( "f", "turns on a flag" );
        OptionSpec<Integer> count = parser.accepts( "c" ).withRequiredArg()
            .describedAs( "count" ).ofType( Integer.class );
        OptionSpec<Double> quantity = parser.accepts( "q" ).withOptionalArg()
            .describedAs( "quantity" ).ofType( Double.class );
        OptionSpec<Void> verbose =
            parser.acceptsAll( asList( "v", "talkative", "chatty" ),
                "behave more verbosely" );
        OptionSpec<File> file = parser.accepts( "output-file" ).withOptionalArg()
            .describedAs( "file" ).ofType( File.class );
        OptionSpec<Void> help = parser.acceptsAll( asList( "h", "?" ),
            "shows this help message" );
        OptionSpec<File> path = parser.acceptsAll( asList( "cp", "classpath" ) )
            .withRequiredArg()
            .describedAs( "path1" + pathSeparatorChar + "path2:..." )
            .ofType( File.class )
            .withValuesSeparatedBy( pathSeparatorChar );

        OptionSet options = parser.parse( args );

        if ( options.has( help ) )
            parser.printHelpOn( System.out );
        else {
            Command command = new Command( System.out );

            command.setFlag( options.has( flag ) );
            command.setOperateVerbosely( options.has( verbose ) );

            if ( options.has( count ) )
                command.setCount( options.valueOf( count ) );
            if ( options.hasArgument( quantity ) )
                command.setQuantity( options.valueOf( quantity ) );
            File outputFile = options.valueOf( file );
            if ( outputFile != null )
                command.setOutput( new FileWriter( outputFile ) );

            command.setPath( options.valuesOf( path ) );

            if ( command.isReady() )
                command.execute();
            else
                System.err.println( "command not ready" );
        }
    }
}
